import { isAPromise, isPresent } from 'utils/js-utils';
import Rx from 'rx-lite';

const IS_ERROR = (status) => status >= 300;

const analyticsSetVar = (type, payload) => {
  window.serverError = payload;
};

const validateStatus = (resp) => {
  const secondTry = resp.clone();

  if (IS_ERROR(resp.status)) {
    throw resp;
  }

  return resp.json().catch(() => {
    return secondTry.text().catch(() => {
      return {};
    });
  });
};

const handleSuccess = (o, json) => {
  let { d = {} } = json;
  d = d || {};

  if (d.Status === 'Fail' || isPresent(d.Errors)) {
    analyticsSetVar('serverError', json);
    o.onError(json);
    o.onCompleted();
  } else {
    o.onNext(json);
    o.onCompleted();
  }
};

const handleError = (o, promise) => {
  if (!isAPromise(promise)) {
    analyticsSetVar('serverError', promise);
    o.onError(new Error(promise.statusText || 'There was an error.'));
    o.onCompleted();
  } else {
    promise.json()
      .then((errorObj) => {
        analyticsSetVar('serverError', errorObj);
        o.onError(errorObj);
        o.onCompleted();
      });
  }
};

export const get = ({ url, headers = {}, options = {} } = {}) =>
  Rx.Observable.create((observer) => {
    return fetch(url, {
      method: 'GET',
      ...options,
      headers: {
        ...headers
      }
    })
      .then((response) => validateStatus(response))
      .then((json) => handleSuccess(observer, json))
      .catch((errPromise) => handleError(observer, errPromise));
  });

export const post = ({ url, payload, headers = {}, options = {} } = {}) =>
  Rx.Observable.create((observer) => {
    return fetch(url, {
      method: 'POST',
      ...options,
      headers: {
        ...headers
      },
      body: JSON.stringify(payload)
    })
      .then((response) => validateStatus(response))
      .then((json) => handleSuccess(observer, json))
      .catch((errPromise) => handleError(observer, errPromise));
  });
