import Rx from 'rx-lite';

export const BREAKPOINTS = {
  palm: 'max-width: 480px',
  portrait: 'max-width: 767px',
  mid: 'min-width: 768px',
  portable: 'max-width: 1023px',
  desk: 'min-width: 1024px',
  large: 'min-width: 1440px'
};

export const watch = () => {
  return Rx.Observable.create((o) => {
    o.onNext(window.innerWidth);
    window.addEventListener('resize', (e) => o.onNext(e.currentTarget.innerWidth));
  });
};

export const Breakpoints = {};

for (let bp in BREAKPOINTS) {
  const dir = BREAKPOINTS[bp].split(':')[0];
  const px = parseInt(BREAKPOINTS[bp].split(':')[1].split('px')[0]);

  const greaterThan = (curWidth, testWidth) =>
    curWidth >= testWidth;
  const lessThan = (curWidth, testWidth) =>
    curWidth <= testWidth;

  let testFunc;

  switch (dir) {
    case 'max-width':
      testFunc = lessThan;
      break;
    case 'min-width':
      testFunc = greaterThan;
      break;
  }

  Breakpoints[bp] = (windowWidth = window.innerWidth) =>
    testFunc(windowWidth, px);
}
