import {
  NAME,
  EMAIL,
  ZIPCODE,
  STREET_ADDRESS,
  CITY,
  PASSWORD,
  SSN,
  LAST_FOUR,
  CC_USER_NAME
} from 'utils/validation-regex';

import moment from 'moment';
import Payment from 'payment';

function matchesRegex (value = '', regex) {
  const matches = value.match(new RegExp(regex));

  if (matches && matches.length) {
    return [];
  }

  return ['Incorrect format.'];
}

function minMaxLength (value, min, max) {
  const notTooLong = value.length <= max;
  const notTooShort = value.length >= min;
  const message = min === max
    ? [`Must be ${min} characters in length.`]
    : [`Minimum length is ${min} characters, maximum length is ${max} characters.`];

  return notTooLong && notTooShort
    ? []
    : message;
}

export function required (value) {
  return !value ? ['This field cannot be empty.'] : [];
}

export const emailPattern = (value) =>
  matchesRegex(value, EMAIL);

export const emailLength = (value) =>
  minMaxLength(value, 2, 40);

export const nameLength = (value) =>
  minMaxLength(value, 2, 30);

export const namePattern = (value) =>
  matchesRegex(value, NAME);

export const zipLength = (value) =>
  minMaxLength(value, 5, 5);

export const zipPattern = (value) =>
  matchesRegex(value, ZIPCODE);

export const streetAddressPattern = (value) =>
  matchesRegex(value, STREET_ADDRESS);

export const cityPattern = (value) =>
  matchesRegex(value, CITY);

export const cityLength = (value) =>
  minMaxLength(value, 3, 50);

export const streetLength = (value) =>
  minMaxLength(value, 5, 50);

export const passwordPattern = (value) =>
  matchesRegex(value, PASSWORD);

export const passwordLength = (value) =>
  minMaxLength(value, 8, 50);

export const is18 = (value) => {
  return moment(new Date(value)).isBefore(moment().subtract(18, 'y'))
    ? []
    : ['You must be at least 18 years old to continue.'];
};

export const validDate = (value) => {
  return moment(value, 'MM/DD/YYYY', true).isValid()
    ? []
    : ['The date you entered is invalid.'];
};

export const ssnPattern = (value) =>
  matchesRegex(value, SSN);

export const lastFourPattern = (value) =>
  matchesRegex(value, LAST_FOUR);

export const ccUserPattern = (value) =>
  matchesRegex(value, CC_USER_NAME);

export const ccNameLength = (value) =>
      minMaxLength(value, 2, 50);

export function cardNumber (value = '') {
  if (value.length > 19) {
    return ['Your card number exceeds 16 characters.'];
  }
  return !Payment.fns.validateCardNumber(value) ? ['Your card number is invalid.'] : [];
}

export function expiry (value = '') {
  const mo = value.split('/')[0] || '';
  const yr = value.split('/')[1] || '';
  const is4Chars = yr.length === 5;

  let errArray = [];

  if (!is4Chars) {
    errArray.push('Invalid expiration date. Expected format is MM / YYYY');
  }

  if (!Payment.fns.validateCardExpiry(mo, yr)) {
    errArray.push('Your card\'s expiration is invalid.');
  }

  return errArray;
}

export function cvv (value = '', type = 'visa') {
  return !Payment.fns.validateCardCVC(value, type) ? ['The CVV you entered is invalid.'] : [];
}
