import React from 'react';
import LinkWithProps from 'components/LinkWithProps';
import { shallow } from 'enzyme';

describe('(Component) LinkWithProps', () => {
  let _props, _spies, _wrapper;

  beforeEach(() => {
    _spies = {};
    _props = {
      prop1: 'test prop',
      prop2: 'test prop number 2',
      text: 'Click me',
      onClick: (_spies.onClick = sinon.spy())
    };
    _wrapper = shallow(<LinkWithProps {..._props} />);
  });

  it('Should dispatch `onClick` when clicked, with hashed props as the argument', () => {
    _wrapper.find('a').simulate('click');
    _spies.onClick.should.have.been.calledWith(_props);
  });

  it('Should render its text based on the `text` prop', () => {
    expect(_wrapper.find('a')).to.have.text(_props.text);
  });

  it('Should render children passed to it instead of text if it is provided', () => {
    _wrapper.setProps({ text: '', children: [<h1 key={1}>Hi</h1>] });
    expect(_wrapper.find('a')).to.have.text(_props.children);
  });
});
