import computedOption from 'helpers/ComputedOption';

describe('(Helper) ComputedOption', () => {
  let passedVal;
  let opts;
  let defaultVal;

  beforeEach(() => {
    passedVal = 12;
    opts = [5, 10, 15, 30];
    defaultVal = 30;
  });

  it('Should be a function', () => {
    expect(computedOption).to.be.a('function');
  });

  it('Should return the default value if the passed value does not exist in options', () => {
    expect(computedOption(passedVal, opts, defaultVal)).to.equal(30);
  });

  it('Should return the passedVal if it exists in options', () => {
    expect(computedOption(15, opts, defaultVal)).to.equal(15);
  });

  it('Should assert an error if no defaultVal is provided, and the passedVal does not exist in options', () => {
    try {
      computedOption(12, opts);
    } catch (err) {
      expect(err).to.be.an('error');
    }
  });

  describe('If the passedVal is not in the correct format, but exists in options', () => {
    it('Should return the passedVal if it is a stringified version of a number', () => {
      expect(computedOption('15', opts, defaultVal)).to.equal('15');
    });

    it('Should return the passedVal if it is the number version of a string', () => {
      expect(computedOption(15, ['15', '20'], defaultVal)).to.equal(15);
    });
  });
});
