import {
  BREAKPOINTS,
  watch,
  Breakpoints
} from 'helpers/Responsive';

import Rx from 'rx-lite';

describe('(Helper) Responsive', () => {
  it('Should export a configurable `BREAKPOINTS` object', () => {
    expect(BREAKPOINTS).to.be.an('object');
  });

  it('Should export a `watch` function', () => {
    expect(watch).to.be.a('function');
  });

  it('Should export a `Breakpoints` object containing functions', () => {
    expect(Breakpoints).to.be.an('object');
    expect(Breakpoints.mid).to.be.a('function');
  });

  describe('The `watch` function', () => {
    it('Should return an Rx Observable', () => {
      expect(watch()).to.be.an.instanceOf(Rx.Observable);
    });

    it('Should be subscribable', () => {
      expect(watch().subscribe());
    });
  });

  describe('The `Breakpoints` exported object', () => {
    it('Should contain a function representative of each key in `BREAKPOINTS`', () => {
      Object.keys(BREAKPOINTS).forEach((k) => {
        expect(Breakpoints[k]).to.exist;
        expect(Breakpoints[k]).to.be.a('function');
      });
    });

    it('Should return a boolean from those functions', () => {
      expect(Breakpoints.palm()).to.be.a('boolean');
    });

    describe('An example function within `Breakpoints`', () => {
      it('Should return a boolean of `true` if windowWidth is less than defined px', () => {
        expect(Breakpoints.palm(360)).to.equal(true);
      });

      it('Should return a boolean of `false` if windowWidth is greater than defined px', () => {
        expect(Breakpoints.palm(500)).to.equal(false);
      });
    });
  });
});
