import setDot from 'helpers/SetDot';

describe('(Helpers) SetDot', () => {
  let objToSet;
  let dotStr;
  let value;

  beforeEach(() => {
    objToSet = {};
    dotStr = 'user.userName.firstName';
    value = 'foo';
  });

  it('Should be exported as a function', () => {
    expect(setDot).to.be.a('function');
  });

  it('Should return an object', () => {
    expect(setDot()).to.deep.equal({});
  });

  it('Should deeply set a property in the provided object based on the dot-string provided', () => {
    expect(setDot(objToSet, dotStr, value)).to.deep.equal({
      user: {
        userName: {
          firstName: 'foo'
        }
      }
    });

    expect(setDot(objToSet, dotStr, [1, 2, 3])).to.deep.equal({
      user: {
        userName: {
          firstName: [1, 2, 3]
        }
      }
    });

    expect(setDot(objToSet, dotStr, { abbr: 'Mr' })).to.deep.equal({
      user: {
        userName: {
          firstName: { abbr: 'Mr' }
        }
      }
    });
  });

  // it('Should return original object untouched If value is empty, undefined, or null', () => {
  //   expect(setDot(objToSet, dotStr, '')).to.deep.equal(objToSet);
  //   expect(setDot(objToSet, dotStr, undefined)).to.deep.equal(objToSet);
  //   expect(setDot(objToSet, dotStr, null)).to.deep.equal(objToSet);
  // });

  it('Should still set property if value is an empty object or array', () => {
    expect(setDot(objToSet, dotStr, {})).to.deep.equal({
      user: {
        userName: {
          firstName: {}
        }
      }
    });

    expect(setDot(objToSet, dotStr, [])).to.deep.equal({
      user: {
        userName: {
          firstName: []
        }
      }
    });
  });
});
