import * as Validators from 'helpers/Validators';

describe('(Helpers) Validators', () => {
  describe('The `required` validator...', () => {
    let _expectedStr = ['This field cannot be empty.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.required('')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.required('Name')).to.deep.equal([]);
    });
  });

  describe('The `emailPattern` validator...', () => {
    let _expectedStr = ['Incorrect format.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.emailPattern('chris')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.emailPattern('chris@gmail.com')).to.deep.equal([]);
    });
  });

  describe('The `nameLength` validator...', () => {
    let _expectedStr = [`Minimum length is 2 characters, maximum length is 30 characters.`];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.nameLength('s')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.nameLength('Chris')).to.deep.equal([]);
    });
  });

  describe('The `zipLength` validator...', () => {
    let _expectedStr = [`Must be 5 characters in length.`];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.zipLength('12')).to.deep.equal(_expectedStr);
      expect(Validators.zipLength('123456')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.zipLength('12312')).to.deep.equal([]);
    });
  });

  describe('The `zipPattern` validator...', () => {
    let _expectedStr = ['Incorrect format.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.zipPattern('chris')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.zipPattern('75218')).to.deep.equal([]);
    });
  });

  describe('The `emailLength` validator...', () => {
    let _expectedStr = ['Minimum length is 2 characters, maximum length is 40 characters.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.emailLength('c')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.emailLength('chrsMllr@gmail.com')).to.deep.equal([]);
    });
  });

  describe('The `cityLength` validator...', () => {
    let _expectedStr = ['Minimum length is 3 characters, maximum length is 50 characters.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.cityLength('Da')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.cityLength('Dallas')).to.deep.equal([]);
    });
  });

  describe('The `streetLength` validator...', () => {
    let _expectedStr = ['Minimum length is 5 characters, maximum length is 50 characters.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.streetLength('12')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.streetLength('123 Street Way')).to.deep.equal([]);
    });
  });

  describe('The `passwordLength` validator...', () => {
    let _expectedStr = [`Minimum length is 8 characters, maximum length is 50 characters.`];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.passwordLength('12')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.passwordLength('123123123')).to.deep.equal([]);
    });
  });

  describe('The `passwordPattern` validator...', () => {
    let _expectedStr = ['Incorrect format.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.passwordPattern('chris')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.passwordPattern('chris123')).to.deep.equal([]);
    });
  });

  describe('The `is18` validator...', () => {
    let _expectedStr = ['You must be at least 18 years old to continue.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.is18('12/29/2012')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.is18('12/29/1987')).to.deep.equal([]);
    });
  });

  describe('The `validDate` validator...', () => {
    let _expectedStr = ['The date you entered is invalid.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.validDate('02/31/1990')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.validDate('02/27/1990')).to.deep.equal([]);
    });
  });

  describe('The `ssnPattern` validator...', () => {
    let _expectedStr = ['Incorrect format.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.ssnPattern('123-29-')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.ssnPattern('123-23-1234')).to.deep.equal([]);
    });
  });

  describe('The `cardNumber` validator...', () => {
    let _expectedStr = ['Your card number is invalid.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.cardNumber('41')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.required('4111 1111 1111 1111')).to.deep.equal([]);
    });
  });

  describe('The `expiry` validator...', () => {
    let _formatError = ['Invalid expiration date. Expected format is MM / YYYY'];
    let _validationError = ['Your card\'s expiration is invalid.']

    it('Should return the correct error response if validation fails', () => {
      expect(Validators.expiry('12 / 2012')).to.deep.equal(_validationError);
    });

    it('Should return the correct array response if date is in incorrect format', () => {
      expect(Validators.expiry('12 / 20')).to.deep.equal(_formatError);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.required('12 / 2030')).to.deep.equal([]);
    });
  });

  describe('The `cvv` validator...', () => {
    let _expectedStr = ['The CVV you entered is invalid.'];

    it('Should return the correct array response when validation fails', () => {
      expect(Validators.cvv('1')).to.deep.equal(_expectedStr);
    });

    it('Should return empty array when validation passes', () => {
      expect(Validators.cvv('123')).to.deep.equal([]);
    });

    it('Should return correct error response when cvv does not match card type', () => {
      expect(Validators.cvv('123', 'amex')).to.deep.equal(_expectedStr);
      expect(Validators.cvv('1234', 'visa')).to.deep.equal(_expectedStr);
    });
  });
});
